Glaciated Areas | Natural Earth
Description: Includes glaciers and recently de-glaciated areas. About Polygons derived from DCW (Digital Chart of the World), except for Antarctica derived

#

Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales
Search for:

- Home
- Features
- Downloads
- Blog
- Forums
- Corrections
- About

« 1:10m Physical Vectors « Downloads

## Glaciated Areas

Includes glaciers and recently de-glaciated areas.
Download glaciated areas (1.57 MB) version 4.0.0

About

Polygons derived from DCW (Digital Chart of the World), except for Antarctica derived from MOA. Includes name attributes for major polar glaciers. Filtering has aggregated some minor glaciers and eliminated others from the original DCW data.

(below) Glaciated areas near Anchorage, Alaska.

Issues

Needs scale rank attributes.

Note: The original DCW data was collected decades ago. Since then many mountain glaciers have either disappeared or diminished in size. This data theme is deliberately called “glaciated areas” instead of “glaciers” to reflect the changeable character of glacier extents.

Version History

- 4.0.0
- 2.0.0
- 1.3.0
- 1.1.0
- 1.0.0

The master changelog is available on Github »